@@ -2,14 +2,14 @@ import logging
 import threading
 from concurrent.futures import ThreadPoolExecutor
 from multiprocessing.pool import ThreadPool
-from typing import Any
+from typing import Any, Callable
 
 
-def __thread_fn__(event: threading.Event, fn: callable, *args: Any, **kwargs: Any):
+def __thread_fn__(event: threading.Event, fn: Callable, *args: Any, **kwargs: Any):
     pass
 
 
-def RunInThread(fn: callable, *args: Any, executor: ThreadPoolExecutor = None, **kwargs: Any) -> threading.Event:
+def RunInThread(fn: Callable, *args: Any, executor: ThreadPoolExecutor = None, **kwargs: Any) -> threading.Event:
     event = threading.Event()
 
     def thread_fn():
